==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/offazure/kotlin/inputs/ListSitesControllerHealthSummaryPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazure.kotlin.inputs

import com.pulumi.azurenative.offazure.inputs.ListSitesControllerHealthSummaryPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property siteName Site name
 */
public data class ListSitesControllerHealthSummaryPlainArgs(
    public val resourceGroupName: String,
    public val siteName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.offazure.inputs.ListSitesControllerHealthSummaryPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.offazure.inputs.ListSitesControllerHealthSummaryPlainArgs =
        com.pulumi.azurenative.offazure.inputs.ListSitesControllerHealthSummaryPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .siteName(siteName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListSitesControllerHealthSummaryPlainArgs].
 */
@PulumiTagMarker
public class ListSitesControllerHealthSummaryPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var siteName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("miaetotjpuijqxdy")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Site name
     */
    @JvmName("wmbkpeesugljfmvf")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.siteName = mapped
    }

    internal fun build(): ListSitesControllerHealthSummaryPlainArgs =
        ListSitesControllerHealthSummaryPlainArgs(
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            siteName = siteName ?: throw PulumiNullFieldException("siteName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/offazure/kotlin/inputs/ListSitesControllerHealthSummaryPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazure.kotlin.inputs

import com.pulumi.azurenative.offazure.inputs.ListSitesControllerHealthSummaryPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property siteName Site name
 */
public data class ListSitesControllerHealthSummaryPlainArgs(
    public val resourceGroupName: String,
    public val siteName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.offazure.inputs.ListSitesControllerHealthSummaryPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.offazure.inputs.ListSitesControllerHealthSummaryPlainArgs =
        com.pulumi.azurenative.offazure.inputs.ListSitesControllerHealthSummaryPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .siteName(siteName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListSitesControllerHealthSummaryPlainArgs].
 */
@PulumiTagMarker
public class ListSitesControllerHealthSummaryPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var siteName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("dcuwushdfvplpefx")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Site name
     */
    @JvmName("qpgwvmwdggovqiji")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.siteName = mapped
    }

    internal fun build(): ListSitesControllerHealthSummaryPlainArgs =
        ListSitesControllerHealthSummaryPlainArgs(
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            siteName = siteName ?: throw PulumiNullFieldException("siteName"),
        )
}
